@@ -31,7 +31,6 @@
 #include <QDBusObjectPath>
 
 #include "manager_p.h"
-#include "nm-active-connectioninterface.h"
 
 NetworkManager::ActiveConnectionPrivate::ActiveConnectionPrivate(const QString &dbusPath, ActiveConnection *q)
 #ifdef NMQT_STATIC
@@ -39,8 +38,9 @@ NetworkManager::ActiveConnectionPrivate::ActiveConnectionPrivate(const QString &
 #else
     : iface(NetworkManagerPrivate::DBUS_SERVICE, dbusPath, QDBusConnection::systemBus())
 #endif
-    , dhcp4Config(0)
-    , dhcp6Config(0)
+    , dhcp4Config(nullptr)
+    , dhcp6Config(nullptr)
+    , state(ActiveConnection::Unknown)
     , q_ptr(q)
 {
     path = dbusPath;
@@ -74,16 +74,18 @@ NetworkManager::ActiveConnection::ActiveConnection(const QString &path, QObject
     connect(&d->iface, &OrgFreedesktopNetworkManagerConnectionActiveInterface::PropertiesChanged, d, &ActiveConnectionPrivate::propertiesChanged);
 #endif
 #endif
-    
+
 #ifdef NMQT_STATIC
     connect(&d->iface, &OrgFreedesktopNetworkManagerConnectionActiveInterface::PropertiesChanged, d, &ActiveConnectionPrivate::propertiesChanged);
 #endif
-    
+
+#ifndef NMQT_STATIC
     /*
      * Workaround: Re-check connection state before we watch changes in case it gets changed too quickly
      * BUG:352326
      */
     d->recheckProperties();
+#endif
 }
 
 NetworkManager::ActiveConnection::ActiveConnection(ActiveConnectionPrivate &dd, QObject *parent)
@@ -91,18 +93,26 @@ NetworkManager::ActiveConnection::ActiveConnection(ActiveConnectionPrivate &dd,
 {
     Q_D(ActiveConnection);
 
+#ifndef NMQT_STATIC
 #if NM_CHECK_VERSION(1, 4, 0)
     QDBusConnection::systemBus().connect(NetworkManagerPrivate::DBUS_SERVICE, d->path, NetworkManagerPrivate::FDO_DBUS_PROPERTIES,
                                          QLatin1String("PropertiesChanged"), d, SLOT(dbusPropertiesChanged(QString,QVariantMap,QStringList)));
 #else
     connect(&d->iface, &OrgFreedesktopNetworkManagerConnectionActiveInterface::PropertiesChanged, d, &ActiveConnectionPrivate::propertiesChanged);
 #endif
+#endif
 
+#ifdef NMQT_STATIC
+    connect(&d->iface, &OrgFreedesktopNetworkManagerConnectionActiveInterface::PropertiesChanged, d, &ActiveConnectionPrivate::propertiesChanged);
+#endif
+
+#ifndef NMQT_STATIC
     /*
      * Workaround: Re-check connection state before we watch changes in case it gets changed too quickly
      * BUG:352326
      */
     d->recheckProperties();
+#endif
 }
 
 NetworkManager::ActiveConnection::~ActiveConnection()
@@ -398,7 +408,6 @@ void NetworkManager::ActiveConnectionPrivate::propertyChanged(const QString &pro
     } else if (property == QLatin1String("Devices")) {
         devices.clear();
         Q_FOREACH (const QDBusObjectPath & path, qdbus_cast< QList<QDBusObjectPath> >(value)) {
-            qCDebug(NMQT) << "Device append " << path.path();
             devices.append(path.path());
         }
         Q_EMIT q->devicesChanged();
